@@ -1,15 +1,15 @@
 from abc import ABCMeta, abstractmethod
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
 from samtranslator.internal.deprecation_control import deprecated
 from samtranslator.metrics.method_decorator import cw_timer
-from samtranslator.model import PassThroughProperty, PropertyType, ResourceMacro
+from samtranslator.model import PassThroughProperty, Property, PropertyType, ResourceMacro
 from samtranslator.model.eventsources import FUNCTION_EVETSOURCE_METRIC_PREFIX
 from samtranslator.model.exceptions import InvalidEventException
 from samtranslator.model.iam import IAMRolePolicies
 from samtranslator.model.intrinsics import is_intrinsic
 from samtranslator.model.lambda_ import LambdaEventSourceMapping
-from samtranslator.model.types import IS_DICT, IS_STR, PassThrough, is_type
+from samtranslator.model.types import IS_BOOL, IS_DICT, IS_INT, IS_LIST, IS_STR, PassThrough
 from samtranslator.translator.arn_generator import ArnGenerator
 from samtranslator.utils.types import Intrinsicable
 from samtranslator.validator.value_validator import sam_expect
@@ -34,23 +34,23 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
     resource_type: str = None  # type: ignore
     relative_id: str  # overriding the Optional[str]: for event, relative id is not None
     property_types: Dict[str, PropertyType] = {
-        "BatchSize": PropertyType(False, is_type(int)),
+        "BatchSize": PropertyType(False, IS_INT),
         "StartingPosition": PassThroughProperty(False),
         "StartingPositionTimestamp": PassThroughProperty(False),
-        "Enabled": PropertyType(False, is_type(bool)),
-        "MaximumBatchingWindowInSeconds": PropertyType(False, is_type(int)),
-        "MaximumRetryAttempts": PropertyType(False, is_type(int)),
-        "BisectBatchOnFunctionError": PropertyType(False, is_type(bool)),
-        "MaximumRecordAgeInSeconds": PropertyType(False, is_type(int)),
+        "Enabled": PropertyType(False, IS_BOOL),
+        "MaximumBatchingWindowInSeconds": PropertyType(False, IS_INT),
+        "MaximumRetryAttempts": PropertyType(False, IS_INT),
+        "BisectBatchOnFunctionError": PropertyType(False, IS_BOOL),
+        "MaximumRecordAgeInSeconds": PropertyType(False, IS_INT),
         "DestinationConfig": PropertyType(False, IS_DICT),
-        "ParallelizationFactor": PropertyType(False, is_type(int)),
-        "Topics": PropertyType(False, is_type(list)),
-        "Queues": PropertyType(False, is_type(list)),
-        "SourceAccessConfigurations": PropertyType(False, is_type(list)),
+        "ParallelizationFactor": PropertyType(False, IS_INT),
+        "Topics": PropertyType(False, IS_LIST),
+        "Queues": PropertyType(False, IS_LIST),
+        "SourceAccessConfigurations": PropertyType(False, IS_LIST),
         "SecretsManagerKmsKeyId": PropertyType(False, IS_STR),
-        "TumblingWindowInSeconds": PropertyType(False, is_type(int)),
-        "FunctionResponseTypes": PropertyType(False, is_type(list)),
-        "KafkaBootstrapServers": PropertyType(False, is_type(list)),
+        "TumblingWindowInSeconds": PropertyType(False, IS_INT),
+        "FunctionResponseTypes": PropertyType(False, IS_LIST),
+        "KafkaBootstrapServers": PropertyType(False, IS_LIST),
         "FilterCriteria": PropertyType(False, IS_DICT),
         "ConsumerGroupId": PropertyType(False, IS_STR),
         "ScalingConfig": PropertyType(False, IS_DICT),
@@ -98,7 +98,7 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
         return
 
     @cw_timer(prefix=FUNCTION_EVETSOURCE_METRIC_PREFIX)
-    def to_cloudformation(self, **kwargs):  # type: ignore[no-untyped-def] # noqa: too-many-branches
+    def to_cloudformation(self, **kwargs):  # type: ignore[no-untyped-def] # noqa: PLR0912, PLR0915
         """Returns the Lambda EventSourceMapping to which this pull event corresponds. Adds the appropriate managed
         policy to the function's execution role, if such a role is provided.
 
@@ -157,7 +157,7 @@ class PullEventSource(ResourceMacro, metaclass=ABCMeta):
             else:
                 raise InvalidEventException(
                     self.logical_id,
-                    "Property ConsumerGroupId not defined for resource of type {}.".format(self.resource_type),
+                    f"Property ConsumerGroupId not defined for resource of type {self.resource_type}.",
                 )
 
         destination_config_policy: Optional[Dict[str, Any]] = None
@@ -424,9 +424,46 @@ class MQ(PullEventSource):
     property_types: Dict[str, PropertyType] = {
         **PullEventSource.property_types,
         "Broker": PassThroughProperty(True),
+        "DynamicPolicyName": Property(False, IS_BOOL),
     }
 
     Broker: PassThrough
+    DynamicPolicyName: Optional[bool]
+
+    @property
+    def _policy_name(self) -> str:
+        """Generate policy name based on DynamicPolicyName flag and MQ logical ID.
+
+        Policy name is required though its update is "No interuption".
+        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iam-policy.html#cfn-iam-policy-policyname #noqa
+
+        Historically, policy name was hardcoded as `SamAutoGeneratedAMQPolicy` but it led to a policy name clash
+        and failure to deploy, if a Function had at least 2 MQ event sources.
+        Since policy is attached to the Lambda execution role,
+        policy name should be based on MQ logical ID not to clash with policy names of other MQ event sources.
+        However, to support backwards compatibility, we need to keep policy `SamAutoGeneratedAMQPolicy` by default,
+        because customers might have code which relys on that policy name consistancy.
+
+        To support both old policy name and ability to have more than one MQ event source, we introduce new field
+        `DynamicPolicyName` which when set to true will use MQ logical ID to generate policy name.
+
+        Q: Why to introduce a new field and not to make policy name dynamic by default if there are multiple
+        MQ event sources?
+        A: Since a customer could have a single MQ source and rely on it's policy name in their code. If that customer
+        decides to add a new MQ source, they don't want to change the policy name for the first MQ all over their
+        code base. But they can opt in using a dynamic policy name for all other MQ sources they add.
+
+        Q: Why not use dynamic policy names automatically for all MQ event sources but first?
+        A: SAM-T doesn't have state and doesn't know what was the CFN resource attribute in a previous transformation.
+        Hence, trying to "use dynamic policy names automatically for all MQ event sources but first" can rely only
+        on event source order. If a customer added a new MQ source __before__ an old one, an old one would receive
+        a dynamic name and would break (potentially) customer's code.
+
+        Returns
+        -------
+            Name of the policy which will be attached to the Lambda Execution role.
+        """
+        return f"{self.logical_id}AMQPolicy" if self.DynamicPolicyName else "SamAutoGeneratedAMQPolicy"
 
     def get_event_source_arn(self) -> Optional[PassThrough]:
         return self.Broker
@@ -438,7 +475,7 @@ class MQ(PullEventSource):
         basic_auth_uri = self._validate_source_access_configurations(["BASIC_AUTH", "VIRTUAL_HOST"], "BASIC_AUTH")
 
         document = {
-            "PolicyName": "SamAutoGeneratedAMQPolicy",
+            "PolicyName": self._policy_name,
             "PolicyDocument": {
                 "Statement": [
                     {
@@ -483,7 +520,6 @@ class SelfManagedKafka(PullEventSource):
         "SASL_SCRAM_512_AUTH",
         "BASIC_AUTH",
         "CLIENT_CERTIFICATE_TLS_AUTH",
-        "SERVER_ROOT_CA_CERTIFICATE",
     ]
 
     def get_event_source_arn(self) -> Optional[PassThrough]:
@@ -521,11 +557,15 @@ class SelfManagedKafka(PullEventSource):
 
     def generate_policy_document(self, source_access_configurations: List[Any]):  # type: ignore[no-untyped-def]
         statements = []
-        authentication_uri, has_vpc_config = self.get_secret_key(source_access_configurations)
+        authentication_uri, authentication_uri_2, has_vpc_config = self.get_secret_key(source_access_configurations)
         if authentication_uri:
             secret_manager = self.get_secret_manager_secret(authentication_uri)  # type: ignore[no-untyped-call]
             statements.append(secret_manager)
 
+        if authentication_uri_2:
+            secret_manager = self.get_secret_manager_secret(authentication_uri)  # type: ignore[no-untyped-call]
+            statements.append(secret_manager)
+
         if has_vpc_config:
             vpc_permissions = self.get_vpc_permission()
             statements.append(vpc_permissions)
@@ -543,10 +583,11 @@ class SelfManagedKafka(PullEventSource):
             "PolicyName": "SelfManagedKafkaExecutionRolePolicy",
         }
 
-    def get_secret_key(self, source_access_configurations: List[Any]):  # type: ignore[no-untyped-def]
+    def get_secret_key(self, source_access_configurations: List[Any]) -> Tuple[Optional[str], Optional[str], bool]:
         authentication_uri = None
         has_vpc_subnet = False
         has_vpc_security_group = False
+        authentication_uri_2 = None
 
         if not isinstance(source_access_configurations, list):
             raise InvalidEventException(
@@ -572,6 +613,10 @@ class SelfManagedKafka(PullEventSource):
                 self.validate_uri(config.get("URI"), "auth mechanism")
                 authentication_uri = config.get("URI")
 
+            elif config.get("Type") == "SERVER_ROOT_CA_CERTIFICATE":
+                self.validate_uri(config.get("URI"), "SERVER_ROOT_CA_CERTIFICATE")
+                authentication_uri_2 = config.get("URI")
+
             else:
                 raise InvalidEventException(
                     self.relative_id,
@@ -583,21 +628,19 @@ class SelfManagedKafka(PullEventSource):
                 self.relative_id,
                 "VPC_SUBNET and VPC_SECURITY_GROUP in SourceAccessConfigurations for SelfManagedKafka must be both provided.",
             )
-        return authentication_uri, (has_vpc_subnet and has_vpc_security_group)
+        return authentication_uri, authentication_uri_2, (has_vpc_subnet and has_vpc_security_group)
 
     def validate_uri(self, uri: Optional[Any], msg: str) -> None:
         if not uri:
             raise InvalidEventException(
                 self.relative_id,
-                "No {} URI property specified in SourceAccessConfigurations for self managed kafka event.".format(msg),
+                f"No {msg} URI property specified in SourceAccessConfigurations for self managed kafka event.",
             )
 
         if not isinstance(uri, str) and not is_intrinsic(uri):
             raise InvalidEventException(
                 self.relative_id,
-                "Wrong Type for {} URI property specified in SourceAccessConfigurations for self managed kafka event.".format(
-                    msg
-                ),
+                f"Wrong Type for {msg} URI property specified in SourceAccessConfigurations for self managed kafka event.",
             )
 
     def get_secret_manager_secret(self, authentication_uri):  # type: ignore[no-untyped-def]
@@ -622,7 +665,7 @@ class SelfManagedKafka(PullEventSource):
         }
 
     @staticmethod
-    @deprecated(None)
+    @deprecated()
     def get_kms_policy(secrets_manager_kms_key_id: str) -> Dict[str, Any]:
         return {
             "Action": ["kms:Decrypt"],
