@@ -1,12 +1,12 @@
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from samtranslator.model.exceptions import ExceptionWithMessage
-from samtranslator.public.sdk.resource import SamResourceType
 from samtranslator.public.intrinsics import is_intrinsics
+from samtranslator.public.sdk.resource import SamResourceType
 from samtranslator.swagger.swagger import SwaggerEditor
 
 
-class Globals(object):
+class Globals:
     """
     Class to parse and process Globals section in SAM template. If a property is specified at Global section for
     say Function, then this class will add it to each resource of AWS::Serverless::Function type.
@@ -32,9 +32,11 @@ class Globals(object):
             "VpcConfig",
             "Environment",
             "Tags",
+            "PropagateTags",
             "Tracing",
             "KmsKeyArn",
             "AutoPublishAlias",
+            "AutoPublishAliasAllProperties",
             "Layers",
             "DeploymentPreference",
             "RolePath",
@@ -61,6 +63,7 @@ class Globals(object):
             "DefinitionUri",
             "CacheClusterEnabled",
             "CacheClusterSize",
+            "MergeDefinitions",
             "Variables",
             "EndpointConfiguration",
             "MethodSettings",
@@ -73,6 +76,8 @@ class Globals(object):
             "TracingEnabled",
             "OpenApiVersion",
             "Domain",
+            "AlwaysDeploy",
+            "PropagateTags",
         ],
         SamResourceType.HttpApi.value: [
             "Auth",
@@ -84,15 +89,17 @@ class Globals(object):
             "Domain",
             "RouteSettings",
             "FailOnWarnings",
+            "PropagateTags",
         ],
         SamResourceType.SimpleTable.value: ["SSESpecification"],
+        SamResourceType.StateMachine.value: ["PropagateTags"],
     }
     # unreleased_properties *must be* part of supported_properties too
     unreleased_properties: Dict[str, List[str]] = {
         SamResourceType.Function.value: ["RuntimeManagementConfig"],
     }
 
-    def __init__(self, template):  # type: ignore[no-untyped-def]
+    def __init__(self, template) -> None:  # type: ignore[no-untyped-def]
         """
         Constructs an instance of this object
 
@@ -140,7 +147,7 @@ class Globals(object):
             del template[cls._KEYWORD]
 
     @classmethod
-    def fix_openapi_definitions(cls, template):  # type: ignore[no-untyped-def]
+    def fix_openapi_definitions(cls, template: Dict[str, Any]) -> None:
         """
         Helper method to postprocess the resources to make sure the swagger doc version matches
         the one specified on the resource with flag OpenApiVersion.
@@ -153,7 +160,6 @@ class Globals(object):
         To make sure we don't modify customer defined swagger, we also check for __MANAGE_SWAGGER flag.
 
         :param dict template: SAM template
-        :return: Modified SAM template with corrected swagger doc matching the OpenApiVersion.
         """
         resources = template.get("Resources", {})
 
@@ -185,24 +191,22 @@ class Globals(object):
         :raises: InvalidResourceException if the input contains properties that we don't support
         """
 
-        globals = {}
+        _globals = {}
         if not isinstance(globals_dict, dict):
-            raise InvalidGlobalsSectionException(self._KEYWORD, "It must be a non-empty dictionary")  # type: ignore[no-untyped-call]
+            raise InvalidGlobalsSectionException(self._KEYWORD, "It must be a non-empty dictionary")
 
         for section_name, properties in globals_dict.items():
             resource_type = self._make_resource_type(section_name)  # type: ignore[no-untyped-call]
 
             if resource_type not in self.supported_properties:
-                raise InvalidGlobalsSectionException(  # type: ignore[no-untyped-call]
+                raise InvalidGlobalsSectionException(
                     self._KEYWORD,
-                    "'{section}' is not supported. "
-                    "Must be one of the following values - {supported}".format(
-                        section=section_name, supported=self.supported_resource_section_names
-                    ),
+                    f"'{section_name}' is not supported. "
+                    f"Must be one of the following values - {self.supported_resource_section_names}",
                 )
 
             if not isinstance(properties, dict):
-                raise InvalidGlobalsSectionException(self._KEYWORD, "Value of ${section} must be a dictionary")  # type: ignore[no-untyped-call]
+                raise InvalidGlobalsSectionException(self._KEYWORD, "Value of ${section} must be a dictionary")
 
             supported = self.supported_properties[resource_type]
             supported_displayed = [
@@ -210,24 +214,22 @@ class Globals(object):
             ]
             for key, _ in properties.items():
                 if key not in supported:
-                    raise InvalidGlobalsSectionException(  # type: ignore[no-untyped-call]
+                    raise InvalidGlobalsSectionException(
                         self._KEYWORD,
-                        "'{key}' is not a supported property of '{section}'. "
-                        "Must be one of the following values - {supported}".format(
-                            key=key, section=section_name, supported=supported_displayed
-                        ),
+                        f"'{key}' is not a supported property of '{section_name}'. "
+                        f"Must be one of the following values - {supported_displayed}",
                     )
 
             # Store all Global properties in a map with key being the AWS::Serverless::* resource type
-            globals[resource_type] = GlobalProperties(properties)  # type: ignore[no-untyped-call]
+            _globals[resource_type] = GlobalProperties(properties)
 
-        return globals
+        return _globals
 
     def _make_resource_type(self, key):  # type: ignore[no-untyped-def]
         return self._RESOURCE_PREFIX + key
 
 
-class GlobalProperties(object):
+class GlobalProperties:
     """
     Object holding the global properties of given type. It also contains methods to perform a merge between
     Global & resource-level properties. Here are the different cases during the merge and how we handle them:
@@ -347,7 +349,7 @@ class GlobalProperties(object):
 
     """
 
-    def __init__(self, global_properties):  # type: ignore[no-untyped-def]
+    def __init__(self, global_properties) -> None:  # type: ignore[no-untyped-def]
         self.global_properties = global_properties
 
     def merge(self, local_properties):  # type: ignore[no-untyped-def]
@@ -368,8 +370,8 @@ class GlobalProperties(object):
         :return: Merged result
         """
 
-        token_global = self._token_of(global_value)  # type: ignore[no-untyped-call]
-        token_local = self._token_of(local_value)  # type: ignore[no-untyped-call]
+        token_global = self._token_of(global_value)
+        token_local = self._token_of(local_value)
 
         # The following statements codify the rules explained in the doctring above
         if token_global != token_local:
@@ -384,7 +386,7 @@ class GlobalProperties(object):
         if self.TOKEN.LIST == token_global == token_local:
             return self._merge_lists(global_value, local_value)  # type: ignore[no-untyped-call]
 
-        raise TypeError("Unsupported type of objects. GlobalType={}, LocalType={}".format(token_global, token_local))
+        raise TypeError(f"Unsupported type of objects. GlobalType={token_global}, LocalType={token_local}")
 
     def _merge_lists(self, global_list, local_list):  # type: ignore[no-untyped-def]
         """
@@ -409,8 +411,7 @@ class GlobalProperties(object):
         # Local has higher priority than global. So iterate over local dict and merge into global if keys are overridden
         global_dict = global_dict.copy()
 
-        for key in local_dict.keys():
-
+        for key in local_dict:
             if key in global_dict:
                 # Both local & global contains the same key. Let's do a merge.
                 global_dict[key] = self._do_merge(global_dict[key], local_dict[key])  # type: ignore[no-untyped-call]
@@ -432,24 +433,23 @@ class GlobalProperties(object):
         """
         return local_value
 
-    def _token_of(self, input):  # type: ignore[no-untyped-def]
+    def _token_of(self, _input: Any) -> str:
         """
         Returns the token type of the input.
 
-        :param input: Input whose type is to be determined
+        :param _input: Input whose type is to be determined
         :return TOKENS: Token type of the input
         """
 
-        if isinstance(input, dict):
-
+        if isinstance(_input, dict):
             # Intrinsic functions are always dicts
-            if is_intrinsics(input):
+            if is_intrinsics(_input):
                 # Intrinsic functions are handled *exactly* like a primitive type because
                 # they resolve to a primitive type when creating a stack with CloudFormation
                 return self.TOKEN.PRIMITIVE
             return self.TOKEN.DICT
 
-        if isinstance(input, list):
+        if isinstance(_input, list):
             return self.TOKEN.LIST
 
         return self.TOKEN.PRIMITIVE
@@ -471,10 +471,10 @@ class InvalidGlobalsSectionException(ExceptionWithMessage):
         message -- explanation of the error
     """
 
-    def __init__(self, logical_id, message):  # type: ignore[no-untyped-def]
+    def __init__(self, logical_id, message) -> None:  # type: ignore[no-untyped-def]
         self._logical_id = logical_id
         self._message = message
 
     @property
-    def message(self):  # type: ignore[no-untyped-def]
-        return "'{}' section is invalid. {}".format(self._logical_id, self._message)
+    def message(self) -> str:
+        return f"'{self._logical_id}' section is invalid. {self._message}"
